import royalnet.version as rv
from royalnet.constellation.api import *


class ApiRoyalnetVersionStar(ApiStar):
    path = "/api/royalnet/version/v1"

    async def api(self, data: ApiData) -> dict:
        return {
            "semantic": rv.semantic
        }



from typing import *
import datetime
import royalnet.utils as ru
from royalnet.constellation.api import *
from ..tables.tokens import Token
from sqlalchemy import and_


class ApiTokenCreateStar(ApiStar):
    path = "/api/token/create/v1"

    async def api(self, data: ApiData) -> dict:
        user = await data.user()
        try:
            duration = int(data["duration"])
        except ValueError:
            raise InvalidParameterError("Duration is not a valid integer")
        new_token = Token.generate(self.alchemy, user, datetime.timedelta(seconds=duration))
        data.session.add(new_token)
        await data.session_commit()
        return new_token.json()



import datetime
import royalnet.utils as ru
from royalnet.constellation.api import *
from ..tables.users import User
from ..tables.aliases import Alias


class ApiTokenInfoStar(ApiStar):
    path = "/api/token/info/v1"

    async def api(self, data: ApiData) -> dict:
        token = await data.token()
        return token.json()



from typing import *
from json import JSONDecodeError
from abc import *
from starlette.requests import Request
from starlette.responses import JSONResponse
from ..pagestar import PageStar
from .jsonapi import api_error, api_success
from .apidata import ApiData
from .apierrors import *
from royalnet.utils import sentry_exc


class ApiStar(PageStar, ABC):
    async def page(self, request: Request) -> JSONResponse:
        if request.query_params:
            data = request.query_params
        else:
            try:
                data = await request.json()
            except JSONDecodeError:
                data = {}
        apidata = ApiData(data, self)
        try:
            response = await self.api(apidata)
        except NotFoundError as e:
            return api_error(e, code=404)
        except ForbiddenError as e:
            return api_error(e, code=403)
        except NotImplementedError as e:
            return api_error(e, code=501)
        except BadRequestError as e:
            return api_error(e, code=400)
        except Exception as e:
            sentry_exc(e)
            return api_error(e, code=500)
        else:
            return api_success(response)
        finally:
            await apidata.session_close()

    async def api(self, data: dict) -> dict:
        raise NotImplementedError()



from .asyncify import asyncify
from .sleep_until import sleep_until
from .formatters import andformat, underscorize, ytdldateformat, numberemojiformat, ordinalformat
from .urluuid import to_urluuid, from_urluuid
from .multilock import MultiLock
from .sentry import init_sentry, sentry_exc
from .log import init_logging

__all__ = [
    "asyncify",
    "sleep_until",
    "andformat",
    "underscorize",
    "ytdldateformat",
    "numberemojiformat",
    "ordinalformat",
    "to_urluuid",
    "from_urluuid",
    "MultiLock",
    "init_sentry",
    "sentry_exc",
    "init_logging",
]
